@@ -3,7 +3,7 @@ package Net::APNs::Extended;
 use strict;
 use warnings;
 use 5.008_001;
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use parent qw(Exporter Net::APNs::Extended::Base);
 use Carp qw(croak);
@@ -92,6 +92,11 @@ sub retrieve_error {
     my $data = $self->_read;
     return unless defined $data;
 
+    if ($data eq '') { # connection closed
+        $self->disconnect;
+        return $data;
+    }
+
     my ($command, $status, $identifier) = unpack 'C C L', $data;
     my $error = {
         command    => $command,
